@@ -5,7 +5,7 @@ PloneCollectorNG - A Plone-based bugtracking system
 
 License: see LICENSE.txt
 
-$Id: Collector.py,v 1.198.4.10 2005/05/21 08:13:36 ajung Exp $
+$Id: Collector.py,v 1.198.4.13 2005/11/12 10:19:28 ajung Exp $
 """
 
 import base64, time, random, md5, os, urllib
@@ -15,6 +15,7 @@ from ComputedAttribute import ComputedAttribute
 from AccessControl import  ClassSecurityInfo
 from Acquisition import aq_base
 from Products.CMFCore.CatalogTool import CatalogTool
+from Products.ZCatalog.ZCatalog import ZCatalog
 from BTrees.OOBTree import OOBTree
 from ZODB.POSException import ConflictError
 from Products.Archetypes.BaseBTreeFolder import BaseBTreeFolder 
@@ -928,10 +929,17 @@ registerType(PloneCollectorNG)
 # Check the availability of TextIndexNG(2)
 ##########################################################################
 
-try: import Products.TextIndexNG2; txng_version = 2
+txng_version = None
+
+try: 
+    import Products.TextIndexNG3; 
+    txng_version = 3
 except ImportError:
-    try: import Products.TextIndexNG; txng_version = 1
-    except: txng_version = 0
+    try: 
+        import Products.TextIndexNG2; 
+        txng_version = 2
+    except: 
+        raise RuntimeError('PloneCollectorNG 1.2.8 or higher requires TextIndexNG Version 2 or 3 (http://sf.net/projects/textindexng')
 
 
 class PloneCollectorNGCatalog(CatalogTool):
@@ -941,17 +949,19 @@ class PloneCollectorNGCatalog(CatalogTool):
     meta_type = 'PloneCollectorNG Catalog'
     portal_type = 'PloneCollectorNG Catalog'
 
+    def __init__(self):
+        CatalogTool.__init__(self)
+
     def manage_afterAdd(self, container, item):
-        """ recreate catalog """
+        """ setup indexes and metadata """
+        self._addIndexes()
+        self._addMetadata()
 
-        # We create the indexes and metadata in the manage_afterAdd() hook
-        # an *not+ inside the constructor as usually because we need an
-        # acquisition context inside enumerateIndexes() to retrieve
-        # the issue schema for custom index creation
+    def manage_afterClone(self, item):
+        """ reindex after copy operation """
+        self.reindex_issues()
 
-        self._initIndexes()
-
-    def enumerateIndexes(self):
+    def _addIndexes(self):
 
         if not hasattr(self, 'aq_parent'): return  []   # only through manage_afterAdd()
 
@@ -959,7 +969,7 @@ class PloneCollectorNGCatalog(CatalogTool):
                   ['Creator', 'FieldIndex'],
                   ['created', 'DateIndex'],
                   ['last_action', 'DateIndex'],
-                  ['SearchableText', 'TextIndex'],
+                  ['SearchableText', 'TextIndexNG2'],
                   ['importance', 'FieldIndex'],
                   ['classification', 'FieldIndex'],
                   ['topic', 'FieldIndex'],
@@ -981,42 +991,45 @@ class PloneCollectorNGCatalog(CatalogTool):
                     if widget in ('MultiSelectionWidget', 'SelectionWidget'):
                         custom.append( [f.getName(), 'FieldIndex'] )
                     else:
-                        custom.append( [f.getName(), 'TextIndex'] )
+                        custom.append( [f.getName(), 'TextIndexNG2'] )
                 elif klass in ('DateTimeField', 'IntField', 'FloatField', 'FixedPointField'):
                     custom.append( [f.getName(), 'FieldIndex'] )
                 else:
                     pass
 
-        # Replace TextIndexes with TextIndexNG instances if possible
-        for i in range(len(custom)):
-            k,v = custom[i]
-            if v == 'TextIndex':
-                if txng_version == 1: custom[i][1] = 'TextIndexNG'
-                if txng_version == 2: custom[i][1] = 'TextIndexNG2'
+        # add all indexes
+        for i, pair in enumerate(custom):
 
-        return  custom
+            name, type = custom[i]
+            if type == 'TextIndexNG2':
+                if txng_version == 3: 
+                    type = 'TextIndexNG3'
 
-    def manage_afterClone(self, item):
-        self.reindex_issues()
+            if name in self.indexes():
+                self.delIndex(name)
+            self.addIndex(name, type)
 
-    def enumerateColumns( self ):
+
+    def _addMetadata( self ):
         """Return field names of data to be cached on query results."""
 
         if not hasattr(self, 'aq_parent'): return  []  # only through manage_afterAdd()
 
-        custom = ('Description', 'Title', 'Creator', 'created', 'modified',
+        columns = ('Description', 'Title', 'Creator', 'created', 'modified',
                   'id', 'status', 'topic', 'classification',
                   'importance', 'assigned_to', 'progress_deadline',
                   'progress_percent_done', 'getId', 'numberFollowups',
                   'last_action', 'numberUploads', 'numberReferences'
                   )
-        return custom
 
-    def searchResults(self, REQUEST=None, **kw):
-        """ Bypass searchResults() of the CatalogTool """
-        return self._catalog.searchResults(*(REQUEST,), **kw)
+        for column in columns:
+            try:
+                self.delColumn(column)
+            except:
+                pass
+            
+            self.addColumn(column)
 
-    __call__ = searchResults
 
 def modify_fti(fti):
     # hide unnecessary tabs (usability enhancement)
