@@ -5,7 +5,7 @@ PloneCollectorNG - A Plone-based bugtracking system
 
 License: see LICENSE.txt
 
-$Id: Issue.py,v 1.208.4.8 2005/05/21 08:36:14 ajung Exp $
+$Id: Issue.py,v 1.208.4.9 2005/11/12 15:20:57 ajung Exp $
 """
 
 import os, time, random
@@ -416,14 +416,7 @@ class PloneIssueNG(BaseBTreeFolder, ParentManagedSchema, WatchList, Translateabl
             if comment: obj.title = comment
             obj.manage_permission(View, acquire=1)
             obj.manage_permission(AccessContentsInformation, acquire=1)
-
-            try:
-                # File API
-                obj.manage_upload(data)
-            except:
-                # ATCT File
-                obj.update_data(data, ct)
-
+            obj.setImage(data)
             self._transcript.addUpload(file_id, comment)
 
             self._last_action = 'Upload'
